@@ -3,6 +3,7 @@
 #
 
 from collections import defaultdict
+from datetime import datetime
 from uuid import uuid4
 
 from django.db.models import Q
@@ -354,6 +355,9 @@ class RQLFilterClass:
             })
 
         unquoted_value = self.remove_quotes(str_value)
+        if not unquoted_value:
+            return Q()
+
         if not unquoted_value.startswith(RQL_ANY_SYMBOL):
             unquoted_value = '*' + unquoted_value
 
@@ -802,10 +806,17 @@ class RQLFilterClass:
             dt = parse_date(val)
             if dt is None:
                 raise ValueError
+            return dt
+
         elif filter_type == FilterTypes.DATETIME:
             dt = parse_datetime(val)
             if dt is None:
-                raise ValueError
+                dt = parse_date(val)
+                if dt is None:
+                    raise ValueError
+
+                return datetime(year=dt.year, month=dt.month, day=dt.day)
+            return dt
 
         elif filter_type == FilterTypes.BOOLEAN:
             if val not in (RQL_FALSE, RQL_TRUE):
